@@ -38,16 +38,20 @@ def subst_at_vars(task):
     return 0
 
 
-def PKG_CONFIG_FILES(bld, pc_files, vnum=None):
+def PKG_CONFIG_FILES(bld, pc_files, vnum=None, extra_name=None):
     '''install some pkg_config pc files'''
     dest = '${PKGCONFIGDIR}'
     dest = bld.EXPAND_VARIABLES(dest)
     for f in TO_LIST(pc_files):
-        base=os.path.basename(f)
+        if extra_name:
+            target = f.split('.pc')[0] + extra_name + ".pc"
+        else:
+            target = f
+        base=os.path.basename(target)
         t = bld.SAMBA_GENERATOR('PKGCONFIG_%s' % base,
                                 rule=subst_at_vars,
                                 source=f+'.in',
-                                target=f)
+                                target=target)
         bld.add_manual_dependency(bld.path.find_or_declare(f), bld.env['PREFIX'])
         t.vars = []
         if t.env.RPATH_ON_INSTALL:
@@ -58,7 +62,7 @@ def PKG_CONFIG_FILES(bld, pc_files, vnum=None):
             t.env.PACKAGE_VERSION = vnum
         for v in [ 'PREFIX', 'EXEC_PREFIX', 'LIB_RPATH' ]:
             t.vars.append(t.env[v])
-        bld.INSTALL_FILES(dest, f, flat=True, destname=base)
+        bld.INSTALL_FILES(dest, target, flat=True, destname=base)
 Build.BuildContext.PKG_CONFIG_FILES = PKG_CONFIG_FILES
 
 
